In this portion of Formulaic's documentation, we introduce the high-level
concepts behind formulas, where they are useful, and how to use the
implementation of formulas provided by `formulaic`.

If you are unfamiliar with formulas, a brief introduction is provided in the
[What are formulas?](formulas.md) section. If you are already familiar, you can
skip forward to the [Formula Grammar](grammar.md) and [User Guides](../guides/).

For a more detailed description of how Formulaic parses and materializes
formulas, as well as how to augment and/or control this behavior, please refer
to the [Advanced Usage](../guides/advanced.md) sections.
